==> zio-aws-redshift_2.12-5.19.7.6-sources.jar: zio/aws/redshift/model/GetReservedNodeExchangeOfferingsRequest.scala <==
package zio.aws.redshift.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.redshift.model.primitives.IntegerOptional
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class GetReservedNodeExchangeOfferingsRequest(
    reservedNodeId: String,
    maxRecords: Optional[IntegerOptional] = Optional.Absent,
    marker: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.GetReservedNodeExchangeOfferingsRequest = {
    import GetReservedNodeExchangeOfferingsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.GetReservedNodeExchangeOfferingsRequest
      .builder()
      .reservedNodeId(reservedNodeId: java.lang.String)
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest.ReadOnly =
    zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest
      .wrap(buildAwsValue())
}
object GetReservedNodeExchangeOfferingsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.GetReservedNodeExchangeOfferingsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest =
      zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest(
        reservedNodeId,
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def reservedNodeId: String
    def maxRecords: Optional[IntegerOptional]
    def marker: Optional[String]
    def getReservedNodeId: ZIO[Any, Nothing, String] =
      ZIO.succeed(reservedNodeId)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.GetReservedNodeExchangeOfferingsRequest
  ) extends zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest.ReadOnly {
    override val reservedNodeId: String = impl.reservedNodeId(): String
    override val maxRecords: Optional[IntegerOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.maxRecords())
      .map(value => value: IntegerOptional)
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.GetReservedNodeExchangeOfferingsRequest
  ): zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-redshift_2.13-5.17.123.1-sources.jar: zio/aws/redshift/model/GetReservedNodeExchangeOfferingsRequest.scala <==
package zio.aws.redshift.model
import java.lang.Integer
import zio.aws.redshift.model.primitives.IntegerOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetReservedNodeExchangeOfferingsRequest(
    reservedNodeId: String,
    maxRecords: Option[IntegerOptional] = None,
    marker: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.GetReservedNodeExchangeOfferingsRequest = {
    import GetReservedNodeExchangeOfferingsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.GetReservedNodeExchangeOfferingsRequest
      .builder()
      .reservedNodeId(reservedNodeId: java.lang.String)
      .optionallyWith(
        maxRecords.map(value => IntegerOptional.unwrap(value): Integer)
      )(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest.ReadOnly =
    zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest
      .wrap(buildAwsValue())
}
object GetReservedNodeExchangeOfferingsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.GetReservedNodeExchangeOfferingsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest =
      zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest(
        reservedNodeId,
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def reservedNodeId: String
    def maxRecords: Option[IntegerOptional]
    def marker: Option[String]
    def getReservedNodeId: ZIO[Any, Nothing, String] =
      ZIO.succeed(reservedNodeId)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.GetReservedNodeExchangeOfferingsRequest
  ) extends zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest.ReadOnly {
    override val reservedNodeId: String = impl.reservedNodeId(): String
    override val maxRecords: Option[IntegerOptional] = scala
      .Option(impl.maxRecords())
      .map(value => zio.aws.redshift.model.primitives.IntegerOptional(value))
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.GetReservedNodeExchangeOfferingsRequest
  ): zio.aws.redshift.model.GetReservedNodeExchangeOfferingsRequest.ReadOnly =
    new Wrapper(impl)
}
